@@ -44,35 +44,32 @@ static bool put_dir_rx_mask_set = false;
 
 static void print_put_syntax(void)
 {
-	printf(_("Send files to remote.  Usage:\n"
-			 "  put [options] file(s) (can include wildcards)\n"
-			 "Options:\n"
-			 "  -a, --append         append if destination file exists\n"
-			 "  -D, --delete-after   delete local file after successful transfer\n"
-			 "      --dir-mask=GLOB  enter only directories matching GLOB pattern\n"
-			 "      --dir-rx-mask=REGEXP\n"
-			 "                       enter only directories matching REGEXP pattern\n"
-			 "  -e, --skip-empty     skip empty files\n"
-			 "  -f, --force          overwrite existing destinations, never prompt\n"
-			 "  -H, --nohup          transfer files in background (nohup mode), quits yafc\n"
-			 "  -i, --interactive    prompt before transferring each file\n"
-			 "  -L, --logfile=FILE   specify other logfile used by --nohup\n"
-			 "  -m, --mask=GLOB      put only files matching GLOB pattern\n"
-			 "  -M, --rx-mask=REGEXP put only files matching REGEXP pattern\n"
-			 "  -n, --newer          transfer file if local is newer than remote file\n"
-			 "  -o, --output=DEST    store in remote file/directory DEST\n"
-			 "  -p, --preserve       try to preserve file attributes\n"
-			 "  -P, --parents        append source path to destination\n"
-			 "  -q, --quiet          overrides --verbose\n"
-			 "  -r, --recursive      upload directories recursively\n"
-			 "  -R, --resume         resume broken transfer (restart at EOF)\n"
-			 "  -s, --skip-existing  always skip existing files\n"
-			 "  -S, --stats[=NUM]    set stats transfer threshold; default is always\n"
-			 "  -t, --tagged         transfer (locally) tagged file(s)\n"
-			 "      --type=TYPE      specify transfer type, 'ascii' or 'binary'\n"
-			 "  -v, --verbose        explain what is being done\n"
-			 "  -u, --unique         store in unique filename (if server supports STOU)\n"
-			 "      --help           display this help\n"));
+	show_help(_("Send files to remote."), "put [options] file(s) (can include wildcards)",
+	  _("  -a, --append         append if destination file exists\n"
+			"  -D, --delete-after   delete local file after successful transfer\n"
+			"      --dir-mask=GLOB  enter only directories matching GLOB pattern\n"
+			"      --dir-rx-mask=REGEXP\n"
+			"                       enter only directories matching REGEXP pattern\n"
+			"  -e, --skip-empty     skip empty files\n"
+			"  -f, --force          overwrite existing destinations, never prompt\n"
+			"  -H, --nohup          transfer files in background (nohup mode), quits yafc\n"
+			"  -i, --interactive    prompt before transferring each file\n"
+			"  -L, --logfile=FILE   specify other logfile used by --nohup\n"
+			"  -m, --mask=GLOB      put only files matching GLOB pattern\n"
+			"  -M, --rx-mask=REGEXP put only files matching REGEXP pattern\n"
+			"  -n, --newer          transfer file if local is newer than remote file\n"
+			"  -o, --output=DEST    store in remote file/directory DEST\n"
+			"  -p, --preserve       try to preserve file attributes\n"
+			"  -P, --parents        append source path to destination\n"
+			"  -q, --quiet          overrides --verbose\n"
+			"  -r, --recursive      upload directories recursively\n"
+			"  -R, --resume         resume broken transfer (restart at EOF)\n"
+			"  -s, --skip-existing  always skip existing files\n"
+			"  -S, --stats[=NUM]    set stats transfer threshold; default is always\n"
+			"  -t, --tagged         transfer (locally) tagged file(s)\n"
+			"      --type=TYPE      specify transfer type, 'ascii' or 'binary'\n"
+			"  -v, --verbose        explain what is being done\n"
+			"  -u, --unique         store in unique filename (if server supports STOU)\n"));
 }
 
 static bool put_exclude_func(char *path)
@@ -149,12 +146,21 @@ static void putfile(const char *path, struct stat *sb,
 
 	if(test(opt, PUT_PARENTS)) {
 		char *p = base_dir_xptr(path);
-		asprintf(&dest, "%s/%s/%s", output, p, base_name_ptr(path));
+		if (asprintf(&dest, "%s/%s/%s", output, p, base_name_ptr(path)) == -1)
+    {
+      fprintf(stderr, _("Failed to allocate memory.\n"));
+      free(p);
+      return;
+    }
 		free(p);
 	} else if(test(opt, PUT_OUTPUT_FILE))
 		dest = xstrdup(output);
 	else
-		asprintf(&dest, "%s/%s", output, base_name_ptr(path));
+		if (asprintf(&dest, "%s/%s", output, base_name_ptr(path)) == -1)
+    {
+      fprintf(stderr, _("Failed to allocate memory.\n"));
+      return;
+    }
 
 	path_collapse(dest);
 
@@ -166,7 +172,7 @@ static void putfile(const char *path, struct stat *sb,
 	free(q_dest_dir);
 	free(dest_dir);
 	if(r == -1) {
-		transfer_mail_msg(_("failed to create directory %s\n"), dest_dir);
+		transfer_mail_msg(_("Couldn't create directory: %s\n"), dest_dir);
 		free(dpath);
 		free(dest);
 		return;
@@ -376,13 +382,22 @@ static void putfiles(list *gl, unsigned opt, const char *output)
 					{
 						/*printf("skipping %s\n", path);*/
 					} else {
-						if(!test(opt, PUT_PARENTS)) {
-							asprintf(&recurs_output, "%s/%s",
-									 output ? output : ".", file);
+						if(!test(opt, PUT_PARENTS))
+            {
+							if (asprintf(&recurs_output, "%s/%s",
+									 output ? output : ".", file) == -1)
+              {
+                fprintf(stderr, _("Failed to allocate memory.\n"));
+                continue;
+              }
 						} else
 							recurs_output = xstrdup(output ? output : ".");
 
-						asprintf(&recurs_mask, "%s/*", path);
+						if (asprintf(&recurs_mask, "%s/*", path) == -1)
+            {
+              fprintf(stderr, _("Failed to allocate memory.\n"));
+              continue;
+            }
 						rgl = lglob_create();
 						lglob_glob(rgl, recurs_mask, true, put_exclude_func);
 						free(recurs_mask);
